@@ -291,7 +291,7 @@ def decode_ros_handshake_header(header_str):
     Decode serialized ROS handshake header into a Python dictionary
 
     header is a list of string key=value pairs, each prefixed by a
-    4-byte length field. It is preceeded by a 4-byte length field for
+    4-byte length field. It is preceded by a 4-byte length field for
     the entire header.
 
     @param header_str: encoded header string. May contain extra data at the end.
